executor

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ActionResult

type ActionResult struct {
	ExitCode int
	Stdout   string
	Stderr   string
	Duration time.Duration
	Error    error
}

ActionResult holds the result of a command/script execution.

func ExecuteCommand

func ExecuteCommand(cmd string, timeoutSec int, isolate bool) *ActionResult

ExecuteCommand runs an inline shell command.

func ExecuteScript

func ExecuteScript(path string, args []string, timeoutSec int, isolate bool) *ActionResult

ExecuteScript runs an external script file with optional arguments.

func (*ActionResult) Success

func (r *ActionResult) Success() bool

Success returns true if the action completed without error and exit code 0.

Jump to