Documentation
¶
Index ¶
- Constants
- func CheckSignalFile(signal string) bool
- func GetHookRunDir() string
- func GetStartTime(pid int) (time.Time, error)
- func IsRunning(pid int) bool
- func ReadPID() (int, error)
- func ReadStatus() (string, error)
- func RemovePID()
- func WritePID() error
- func WriteSignalFile(signal string) error
- func WriteStatus(port int, ruleCount int) error
Constants ¶
const ( ReloadSignalFile = "reload.signal" StopSignalFile = "stop.signal" StatusSignalFile = "status.signal" )
Signal file names for Windows IPC.
const PIDFileName = "hookrun.pid"
PIDFileName is the name of the PID file.
Variables ¶
This section is empty.
Functions ¶
func CheckSignalFile ¶
CheckSignalFile checks if a signal file exists and removes it. Returns true if the signal was found.
func GetHookRunDir ¶
func GetHookRunDir() string
GetHookRunDir returns the HookRun data directory (~/.hookrun).
func GetStartTime ¶
GetStartTime reads the process start time.
func WriteSignalFile ¶
WriteSignalFile creates a signal file for Windows IPC.
func WriteStatus ¶
WriteStatus writes current status info for the status command to read.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.